#
# spec file for package gpsd
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         sover 30
%define         libgps libgps%{sover}
%define         libQgps libQgpsmm%{sover}
%define         _udevdir %(pkg-config --variable udevdir udev)
%bcond_without python2
Name:           gpsd
Version:        3.25
Release:        5.7
Summary:        Service daemon for mediating access to a GPS
License:        BSD-3-Clause
Group:          Hardware/Other
URL:            https://gpsd.gitlab.io/gpsd/
Source0:        https://download-mirror.savannah.gnu.org/releases/gpsd/%{name}-%{version}.tar.xz
Source1:        rules.gpsd
Source2:        udev.gpsd
Source3:        sysconfig.gpsd
Source98:       https://download-mirror.savannah.gnu.org/releases/gpsd/%{name}-%{version}.tar.xz.sig
Source99:       %{name}.keyring
Patch0:         harden_gpsd.service.patch
Patch1:         harden_gpsdctl@.service.patch
BuildRequires:  chrpath
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libcap-devel
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  python3-cairo-devel
BuildRequires:  python3-gobject-devel
BuildRequires:  python3-pyserial
BuildRequires:  scons >= 2.3.0
BuildRequires:  systemd-rpm-macros
BuildRequires:  update-desktop-files
BuildRequires:  xmlto
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(bluez)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libusb-1.0)
%if %{with python2}
BuildRequires:  pkgconfig(python2)
%endif
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(udev)
Requires:       udev
Requires(pre):  %fillup_prereq
Requires(pre):  coreutils
%{?systemd_requires}
%if 0%{?suse_version} > 1320 || 0%{?sle_version} >= 120200
BuildRequires:  pps-tools-devel
%endif

%description
gpsd is a service daemon that mediates access to a GPS sensor connected
to the host computer by serial or USB interface, making its data on the
location/course/velocity of the sensor available to be queried on TCP
port 2947 of the host computer.  With gpsd, multiple GPS client
applications (such as navigational and wardriving software) can share
access to a GPS without contention or loss of data.  Also, gpsd
responds to queries with a format that is substantially easier to parse
than NMEA 0183.  A client library is provided for applications.

After installing this RPM, gpsd will automatically connect to USB GPSes
when they are plugged in and requires no configuration.  For serial
GPSes, you will need to start gpsd by hand.  Once connected, the daemon
automatically discovers the correct baudrate, stop bits, and protocol.
The daemon will be quiescent when there are no clients asking for
location information, and copes gracefully when the GPS is unplugged
and replugged.

%package devel
Summary:        Client libraries in C and Python for talking to a running gpsd or GPS
Group:          Development/Libraries/C and C++
Requires:       %{libgps}
Requires:       %{name} = %{version}
Requires:       pkgconfig
Requires:       python3-curses
Requires:       python3-gpsd = %{version}

%description devel
This package provides C header files for the gpsd shared libraries that
manage access to a GPS for applications and debugging tools. You will
need to have gpsd installed for it to work.

%package qt5-devel
Summary:        Development files for libQgpsmm
Group:          Development/Libraries/C and C++
Requires:       %{libQgps}
Requires:       gpsd-devel = %{version}
# TODO: 2023-09-18 The Qt5 wrapper was split from gpsd-devel, replace the
# following line with: 'Conflicts: gpsd-devel < %%{version}' when a new release
# is available
Conflicts:      gpsd-devel < %{version}-%{release}

%description qt5-devel
This package provides headers files for the gpsd Qt5 library.

%package -n %{libgps}
Summary:        Shared library for GPS applications
Group:          System/Libraries

%description -n %{libgps}
This package provides the shared library for gpsd and other GPS aware
applications.

%package -n %{libQgps}
Summary:        Shared Qt library for GPS applications
Group:          System/Libraries

%description -n %{libQgps}
This package provides the shared Qt library for gpsd and other GPS aware
applications.

%package -n python2-gpsd
Summary:        Client libraries in C and Python for talking to a running gpsd or GPS
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Provides:       python-gpsd = %{version}-%{release}
Obsoletes:      python-gpsd < %{version}-%{release}

%description -n python2-gpsd
This package provides python modules and tools for the gpsd shared libraries.
You will need to have gpsd installed for it to work.

%package -n python3-gpsd
Summary:        Client libraries in C and Python3 for talking to a running gpsd or GPS
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}

%description -n python3-gpsd
This package provides python3 modules and tools for the gpsd shared libraries.
You will need to have gpsd installed for it to work.

%package clients
Summary:        Example clients for gpsd
Group:          Hardware/Other
Requires:       python3-cairo
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
Requires:       python3-gpsd
Requires:       python3-serial

%description clients
xgps is a simple test client for gpsd with an X interface. It displays
current GPS position/time/velocity information and (for GPSes that
support the feature) the locations of accessible satellites.

xgpsspeed is a speedometer that uses position information from the GPS.
It accepts an -h option and optional argument as for gps, or a -v
option to dump the package version and exit. Additionally, it accepts
-rv (reverse video) and -nc (needle color) options.

cgps resembles xgps, but without the pictorial satellite display.  It
can run on a serial terminal or terminal emulator.

%prep
%if %{with python2}
mkdir -p %{name}-%{version}/python2
tar -xf %{SOURCE0} -C %{name}-%{version}/python2
pushd %{name}-%{version}/python2/%{name}-%{version}
%patch -P 0
%patch -P 1
popd
%endif
mkdir -p %{name}-%{version}/python3
tar -xf %{SOURCE0} -C %{name}-%{version}/python3
pushd %{name}-%{version}/python3/%{name}-%{version}
%patch -P 0
%patch -P 1
popd

%build

# The SCons description does not handle CXXFLAGS correctly, pass C++ flags also in CFLAGS
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
export CPPFLAGS="%{optflags}"
pyversions=( "python3" )
pylibdir=( "%{python3_sitearch}" )
%if %{with python2}
pyversions+=( "python2" )
pylibdir+=( "%{python2_sitearch}")
%endif
cnt=0
for i in "${pyversions[@]}"; do
    pushd %{name}-%{version}/${i}/%{name}-%{version}

    # breaks with %{?_smp_mflags}
    scons \
        dbus_export=yes \
        systemd=yes \
        libQgpsmm=yes \
        qt=yes \
        qt_versioned=5 \
        leapfetch=no \
        prefix="" \
        sysconfdif=%{_sysconfdir} \
        bindir=%{_bindir} \
        includedir=%{_includedir} \
        libdir=%{_libdir} \
        sbindir=%{_sbindir} \
        mandir=%{_mandir} \
        docdir=%{_docdir}/%{name} \
        icondir=%{_datadir}/icons/hicolor/128x128/apps \
        python_shebang=%{_bindir}/${i} \
        pkgconfigdir=%{_libdir}/pkgconfig \
        udevdir=$(dirname %{_udevrulesdir}) \
        target_python=${i} \
        python_libdir=${pylibdir[$cnt]} \
        unitdir=%{_unitdir} \
        mibdir=%{_datadir}/snmp/mibs/%{name} \
        build

    # Fix python interpreter path.
    sed -e "s,#!%{_bindir}/\(python[23]\?\|env \+python[23]\?\),#!%{_bindir}/${i},g" -i gps/*.py

    popd
    cnt=`expr $cnt + 1`
done

%install
# The SCons description does not handle CXXFLAGS correctly, pass C++ flags also in CFLAGS
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
export CPPFLAGS="%{optflags}"
# Install python2 first
%if %{with python2}
pushd %{name}-%{version}/python2/%{name}-%{version}

DESTDIR=%{buildroot} scons nostrip=True install systemd_install

# Now delete all the installed files except the python2 files
find %{buildroot} \( -not -type d -a -not -path "*/python2.*/*" \) -delete

popd
%endif
pushd %{name}-%{version}/python3/%{name}-%{version}

DESTDIR=%{buildroot} scons nostrip=True install systemd_install

install -d -m 755 %{buildroot}%{_udevdir}
install -d -m 755 %{buildroot}%{_udevdir}/rules.d
install -d -m 755 %{buildroot}%{_fillupdir}
install -d -m 755 %{buildroot}%{_datadir}/applications
install -m 644 %{SOURCE1} %{buildroot}%{_udevdir}/rules.d/51-gpsd.rules
install -m 755 %{SOURCE2} %{buildroot}%{_udevdir}/gpsd.sh
install -m 644 %{SOURCE3} %{buildroot}%{_fillupdir}
# install desktop entries
install -D -m 644 -t %{buildroot}%{_datadir}/applications/ packaging/X11/xgps.desktop
install -D -m 644 -t %{buildroot}%{_datadir}/applications/ packaging/X11/xgpsspeed.desktop
ln -s  	%{_sbindir}/service %{buildroot}%{_sbindir}/rcgpsd

%fdupes -s %{buildroot}%{_mandir}

# strip absolute path and suffix
sed -i -e 's#Icon=.*/\([^/]\+\)\(\..\+\)#Icon=\1#' %{buildroot}%{_datadir}/applications/xgps{,speed}.desktop
%suse_update_desktop_file -r xgpsspeed System Monitor
%suse_update_desktop_file -r xgps System Monitor

%python3_fix_shebang
%if %{suse_version} >= 1600
%python_expand %python3_fix_shebang_path %{buildroot}%{$python_sitearch}/gps/*
%endif

%pre
%service_add_pre gpsd.service gpsdctl@.service gpsd.socket

%post
%if 0%{?suse_version} > 1500
%ldconfig
%else
/sbin/ldconfig
%endif
%fillup_only -n gpsd
%service_add_post gpsd.service gpsdctl@.service gpsd.socket
%udev_rules_update

%preun
%service_del_preun gpsd.service gpsdctl@.service gpsd.socket

%postun
%if 0%{?suse_version} > 1500
%ldconfig
%else
/sbin/ldconfig
%endif
%service_del_postun gpsd.service gpsdctl@.service gpsd.socket

%if 0%{?suse_version} > 1500
%ldconfig_scriptlets -n %{libgps}
%ldconfig_scriptlets -n %{libQgps}
%else
%post -n %{libgps} -p /sbin/ldconfig
%postun -n %{libgps} -p /sbin/ldconfig
%post -n %{libQgps} -p /sbin/ldconfig
%postun -n %{libQgps} -p /sbin/ldconfig
%endif

%files
%license %{name}-%{version}/python3/%{name}-%{version}/COPYING
%{_docdir}/%{name}
%exclude %{_docdir}/%{name}/{COPYING,build.adoc}
%{_mandir}/man1/gpsctl.1%{?ext_man}
%{_mandir}/man8/gpsd.8%{?ext_man}
%{_mandir}/man8/gpsdctl.8%{?ext_man}
%{_mandir}/man8/gpsinit.8%{?ext_man}
%{_udevdir}/gpsd.sh
%{_udevdir}/rules.d/*
%{_unitdir}/gpsd.service
%{_unitdir}/gpsd.socket
%{_unitdir}/gpsdctl@.service
%{_sbindir}/rcgpsd
%{_sbindir}/gpsd
%{_sbindir}/gpsdctl
%{_bindir}/gpsctl
%{_fillupdir}/sysconfig.gpsd

%files -n %{libgps}
%{_libdir}/libgps.so.*
%{_libdir}/libgpsdpacket.so.*

%files -n %{libQgps}
%{_libdir}/libQgpsmm.so.*

%files devel
%doc %{name}-%{version}/python3/%{name}-%{version}/TODO
%{_mandir}/man1/gpscat.1%{?ext_man}
%{_mandir}/man1/gpsfake.1%{?ext_man}
%{_mandir}/man1/gpsdebuginfo.1%{?ext_man}
%{_mandir}/man1/gpsdecode.1%{?ext_man}
%{_mandir}/man1/gpsprof.1%{?ext_man}
%{_mandir}/man3/libgps.3%{?ext_man}
%{_mandir}/man5/gpsd_json.5%{?ext_man}
%{_bindir}/gpsfake
%{_bindir}/gpscat
%{_bindir}/gpsdebuginfo
%{_bindir}/gpsdecode
%{_bindir}/gpsprof
%{_includedir}/gps.h
%{_libdir}/libgps.so
%{_libdir}/libgpsdpacket.so
%{_libdir}/pkgconfig/libgps.pc

%files qt5-devel
%{_mandir}/man3/libgpsmm.3%{?ext_man}
%{_mandir}/man3/libQgpsmm.3%{?ext_man}
%{_includedir}/libgpsmm.h
%{_libdir}/libQgpsmm.so
%{_libdir}/libQgpsmm.prl
%{_libdir}/pkgconfig/Qgpsmm.pc

%if %{with python2}
%files -n python2-gpsd
%{python_sitearch}/gps/
%{python_sitearch}/gps-%{version}.*
%endif

%files -n python3-gpsd
%{python3_sitearch}/gps/
%{python3_sitearch}/gps-%{version}.*

%files clients
%{_mandir}/man1/cgps.1%{?ext_man}
%{_mandir}/man1/gegps.1%{?ext_man}
%{_mandir}/man1/gps.1%{?ext_man}
%{_mandir}/man1/gps2udp.1%{?ext_man}
%{_mandir}/man1/gpscsv.1%{?ext_man}
%{_mandir}/man1/gpsmon.1%{?ext_man}
%{_mandir}/man1/gpspipe.1%{?ext_man}
%{_mandir}/man1/gpsplot.1%{?ext_man}
%{_mandir}/man1/gpsrinex.1%{?ext_man}
%{_mandir}/man1/gpssnmp.1%{?ext_man}
%{_mandir}/man1/gpssubframe.1%{?ext_man}
%{_mandir}/man1/gpxlogger.1%{?ext_man}
%{_mandir}/man1/lcdgps.1%{?ext_man}
%{_mandir}/man1/ntpshmmon.1%{?ext_man}
%{_mandir}/man1/ubxtool.1%{?ext_man}
%{_mandir}/man1/xgps.1%{?ext_man}
%{_mandir}/man1/xgpsspeed.1%{?ext_man}
%{_mandir}/man1/zerk.1%{?ext_man}
%{_mandir}/man8/ppscheck.8%{?ext_man}
%{_bindir}/gegps
%{_bindir}/xgps
%{_bindir}/xgpsspeed
%{_bindir}/cgps
%{_bindir}/lcdgps
%{_bindir}/gpsmon
%{_bindir}/gpspipe
%{_bindir}/gps2udp
%{_bindir}/gpxlogger
%{_bindir}/ntpshmmon
%{_bindir}/ppscheck
%{_bindir}/ubxtool
%{_bindir}/zerk
%{_bindir}/gpsrinex
%{_bindir}/gpscsv
%{_bindir}/gpsplot
%{_bindir}/gpssubframe
%{_bindir}/gpssnmp
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/apps/*
%dir %{_datadir}/snmp
%dir %{_datadir}/snmp/mibs
%dir %{_datadir}/snmp/mibs/%{name}
%{_datadir}/snmp/mibs/gpsd/GPSD-MIB

%changelog
* Mon Apr 29 2024 pgajdos@suse.com
- usage of %%python3_fix_shebang to cover /usr/bin is also
  needed [bsc#1212476]
* Wed Mar 13 2024 pgajdos@suse.com
- remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang_path macro, [bsc#1212476]
* Tue Feb 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Sep 18 2023 Christophe Marin <christophe@krop.fr>
- Split the Qt5 wrapper from gpsd-devel to avoid installing
  unneeded dependencies when building plasma 6 packages
  (boo#1215444)
* Wed Jan 11 2023 Arjen de Korte <suse+build@de-korte.org>
- Update to version 3.25
  * Have ubxtool "-w 0" run forever.
  * Bump libgps version to 30.0
  * Change fixsource_t, store server locally, make pointers const.
  * Move gpsd_hexpack() to gps.h as gps_hexpack()
  * Move gpsd_hexdump() to gps.h as gps_hexdump()
  * Allow gpsctl -s/--ship to work without -f.
  * Grab prRes and quality from u-blox 8+, into JSON, then into xgps.
  * New GPSD-MIB, installed in share/mibs/gpsd.
  * gpssnmp supports GPSD-MIB in pass and pass_persist modes
  * Add decodes for NMEA $xxHDM, $xxROT and $xxXDR
  * Add Magnetic Heading (mheading) and Rate of Rotation (rot) to
    attitude_t
  * Allow NTP time from gpsd://, tcp:// and udp:// sources
  * Add the -B, --nobuffer, option to gpspipe.
  * gpsd opens $RUNDIR/chrony.clk.XXX.sock to supply serial time to
    chronyd.
  * Add -g and --garmin options to gpxlogger for depth.
  * Add -F and --filein options to gpxlogger to read GPSD JSON from a
    file.
- Update gpsd.keyring (DD3DD9BB -> 0C898D47)
* Thu Apr 28 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 3.24
  * NTRIP 2.0 now works.  But still only plain HTML, not RTP, etc.
  * Remove ntrip option and NTRIP_ENABLE.  Always build.
  * Remove passthrough option and PASSTHROUGH_ENABLE. Always build.
  * Remove nmea0183 option and NMEA0183_ENABLE. Always build.
  * Remove netfeed option and NETFEED_ENABLE. Always build.
  * gpsd will retry ntrip:// and tcp:// connections
  * cgps can expand to show more sats. Added --rtk option.
  * maidenhead() checks for input errors.
  * Better SHM logs.
  * PPS and TOFF JSON now include shm used, and real precision.
  * Add initial, untested, TSIPv1 support
  * split debug messages into different syslog() levels.
  * New ppscheck options, and can use /dev/ppsX devices.
  * First try at TSIPv1 protocol decodes.
  * Decode Quectel $PQVERNO for firmware version
  * Decode Skytrak PX1172RH_DS messages.
- Update gpsd.keyring (0C898D47 -> DD3DD9BB)
* Tue Oct 19 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Re-enable LTO on aarch64
* Mon Sep 27 2021 Dirk Stoecker <opensuse@dstoecker.de>
- Set ProtectClock to false or gpsd will not start
* Wed Sep 22 2021 Arjen de Korte <suse+build@de-korte.org>
- Don't use gpsd version in patches (will break with every update)
  %% harden_gpsd.service.patch
  %% harden_gpsdctl@.service.patch
* Wed Sep 22 2021 Arjen de Korte <suse+build@de-korte.org>
- Update to version 3.23.1
  * Improve ubx cycle detection.
  * Add quirks for Jackson Labs nonstandard NMEA
  * Change STATUS_NO_FIX to STATUS_UNK to avoid confusion with fix
    mode.
  * Change STATUS_FIX to STATUS_GPS to avoid confusion with fix
    mode.
  * Change STATUS_DGPS_FIX to STATUS_DGPS to avoid confusion with
    fix mode.
  * Split SOURCE_ACM from SOURCE_USB.  ACM has no speeds.
  * Add speeds 1 mbps, 1.152 mbps, 1.5 mbps, and higher.  When libc
    supports them.
  * Improve autobaud.
  * Add new u-blox M10 messages.
  * Fix u-blox M6, M7 initialization issues.
  * Various ubxtool and gpxlogger updates.
  * Add mtk3301_speed_switcher()
  * No API, ABI changes.
  * Fallback to "python3" if "python" not found.
* Mon Sep 20 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_gpsd.service.patch
  * harden_gpsdctl@.service.patch
* Sat Aug  7 2021 Arjen de Korte <suse+build@de-korte.org>
- Update to version 3.23
  * doc/*xml all moved into www/internals.adoc
  * Convert all DocBook (.xml) to AsciiDoctor (.adoc)
  * Remove all XSL remnants.
  * gpsplot: speedup, add new options.
  * driver_ubx.c: Add decode for UBX-NAV-STATUS
  * gps/ubx.py: Improve decode for UBX-NAV-STATUS
  * cgps: Add popup help, interactive options.
  * Reorganize and split the man pages.
  * Small updates for u-blox M8 and M10
  * Deprecated mtk3331 and ashtech build options.  Use nmea0183
    instead.
  * gpssnmp: Move from contrib/ to clients, add manpage
  * Add www/gpsd-client-example-code.adoc
  * Add gpsdebuginfo script and man page.
  * ubxtool: Add BeiDou, Galileo, GLONASS, QZSS, and partial SBAS
    subframe decodes
  * Max serial port speed raised to 921,600.
  * SUBFRAME JSON now includes new fields to support multiple
    constellations.
  * gpsd: Add some ADR and UDR message partial decodes.
  * ubxtool: Add some ADR and UDR message polls and decodes.
  * Remove COMPASS_ENABLE.  Always compile attitude code.
  * contrib/webgps.py: use argparse, arguments -V, --version,
  - -no-html-head.
  * Add readonly flag to DEVICE JSON.
  * Control messages to gpsd now return JSON, instead of, sometimes,
    OK or ERROR.
  * gpsfake uses "# Date: yyyy-mm-dd" to set initial time.
  * Don't compute wrong GPS rollover after 2021-10-23.
  * Bump libgps to version 29.
* Wed Jun  2 2021 Dirk Müller <dmueller@suse.com>
- disable lto on aarch64 for now (bsc#1187089)
* Sat Jan  9 2021 Arjen de Korte <suse+build@de-korte.org>
- Update to version 3.22
  * Added client/gpscsv to convert gpsd JSON to csv.
  * Added client/gpsplot to dynamically plot gpsd JSON.
  * Added client/gpssubframe to decode gpsd SUBFRAME JSON.
  * Added nSat and uSat to SKY JSON.  Old clients can not read new
    SKY.
  * Move stuff from source root into clients/, include/, gpsmon/
    and libgps/.
  * Move stuff from source root into gpsd/.
  * Move class ubx out of ubxtool and into gps/ubx.py.
  * Build all targets in gpsd-$VERSION/, not in tree.
  * NMEA 4.11 support for $GI (IRNSS) and $GZ (QZSS).
- Remove obsolete sed scripts that no longer serve a purpose
- Use new ldconfig macros in Tumbleweed
* Thu Oct 22 2020 Arjen de Korte <suse+build@de-korte.org>
- Update to version 3.21
  * Create python programs from .in files to allow macro substitution.
  * Finally clean .sconsign*.dblite with "scons -c"
  * Remove revision.h.  Move REVISION into gpsd_config.h
  * Change asciidoc to asciidoctor, and revise documents to match.
  * library version bumped to 27
  * Add leap_seconds to gps_data_t
  * Add/change many rtcm2 structs in gps.h
  * Add/change many rtcm3 structs in gps.h
  * Maindenhead now 8 chars.
  * Add icondir and sharedir install options
  * Install basic doc in sharedir
  * Move gps_data_t->status to gps_fix_t.status for better fix merging
  * The gps python module is now Pure Python + FFI.  FFI only for packet.py
  * User should manually delete any old packet*so.
  * Add wspeedt, wspeedr, wanglem, wanglet, wangler to  gps_fix_t
  * Add "-p CONFIG", "-p STATUS", "-t" and "-tt" options to ubxtool.
  * Add python_shebang option to scons config.
  * gpsrinex has long options and many new options.
  * Added long options to gpsd.
  * Remove unused FORCE_GLOBAL_ENABLE
  * Remove config option reconfigure, replace with -p, --passive runtime option.
  * Remove config option controlsend (RECONFIGURE_ENABLE)
  * Add config option rundir=XX.  Default set to /run, or /var/run as required.
  * Fixes for Python 2.6 up to 3.9.
* Fri Apr 17 2020 Arjen de Korte <suse+build@de-korte.org>
- Update to version 3.20
  * Change README into an asciidoc file and publish HTML from it
  * Add NED and geoid_sep to gps_fix_t and TPV JSON.
  * Add "-e NED" to ubxtool to enable NED messages.
  * gpsdata.separation replaced by gpsdata.fix.geoid_sep.
  * Remove nofloats build option.
  * TPV JSON "alt" is now fixed at WGS84.  Probably.
  * xgps now uses XGPSOPTS environment variable.
  * add health variable to satellite_t
  * change satellite_t elevation and azimuth to double
  * satellite_t elevation, azimuth, and ss use NAN for unknown value.
  * add altMSL, altHAE, and depth, to gps_fix_t
  * altitude in gps_fix_t is deprecated and undefined
  * wgs84_separation() now return EGM2008 computed from 5x5 degree base data.
  * The best results are close to cm, the worst off up to 12m.
  * Move mag_var from gps_device_t to magnetic_var gps_data_t.
  * Added mag_var() to interpolate magnetic variation (deviation) from a table.
  * Remove true2magnetic() as mag_var() improves on it.
  * Remove TIMEHINT_ENABLE.  It only worked when enabled.
  * Remove NTP_ENABLE and NTPSHM_ENABLE.  It only worked when enabled.
  * Remove PPS_ENABLE and TIMING_ENABLE.
  * Add dgps_age and dgps_station to gps_fix_t
  * Convert all timestamp_t to timespec_t.
  * Remove FIXED_PORT_SPEED and FIXED_STOP_BITS build options.
  * Add -s [speed] and -f [framing] runtime options to gpsd.
  * A working CC and termios.h are mandatory.
  * use the current leap second to determine the current GPS epoch.
  * leapfetch.py, leapseconds.cache, timebase.h and leapfetch option gone.
- Remove 0001-Make-sure-Qgpsmm.pc-is-usable.patch (upstreamed)
- Fix legacy socket path
* Mon Mar 16 2020 Tomáš Chvátal <tchvatal@suse.com>
- Allow building without python2 available
* Sat Sep 28 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add 0001-Make-sure-Qgpsmm.pc-is-usable.patch to fix the bogus values
  in qgpsmm.pc
- Update the URLs
* Tue Sep 17 2019 suse+build@de-korte.org
- Update to version 3.19
  * Rearrange rawdata_t.  Bump the API because gps_data_t changed.
  * Report sequence-ID fields in type 7 and 13 AIS messages.
  * Preliminary support for SiRFstar V
  * Improve error modeling.
  * Update pseudo NMEA to v3.0, with fractional time.
  * Improve cycle detection, mostly for NMEA.
  * Move epe from gps_data_t to be near its friends in gps_fix_t.
  * Preliminary u-blox 9 support.
  * Add qErr in gps_data_t to store PPS quantization error.
  * Add Android (AOSP) support
  * Improved multi gnss and multi signal support.
  * NMEA 4.10 multi gnss multi signal support.
  * The arguments to "ubxtool -p P" have been expanded and changed.
  * New options, -g, -x, -z, added to ubxtool for u-blox 9 support.
- Drop gpsd-declaration-in-for-loop.patch
* Mon Dec 10 2018 Arjen de Korte <suse+build@de-korte.org>
- Correct flag to disable stripping (nostrip=True)
- Add gpsd-declaration-in-for-loop.patch to remove c99 construction
  (backport from upstream), fixes building for Leap-42.3
- Upstream changed location of gpsd in systemd gpsd.service file
  (change it back to {_sbindir})
* Sun Nov 25 2018 mardnh@gmx.de
- Update to version 3.18.1
  * Fix some installation issues.
  * A few minor updates to ubxtool and driver_ubx.
  * Add contrib/skyview2svg
- Update to version 3.18.0
  * Add ECEF support to ievermore, italk,Skytraq, SiRF, U-blox drivers.
  * Add ECEF support to JSON, cgps and xgps.
  * Add GREIS (Javad) driver from Virgin Orbit.
  * Add CLI tools zerk and ubxtool to manage JAVAD and u-blox GPS.
  * Add gnssid:svid to satellite_t, cgps and xgps.  PRN will die.
  * Add gnssid:svid to JSON, cgps and xgps.
  * Add stricter version checking (more to todo).
  * More and better regression tests.
  * Better Python dependency checking, at build time and runtime.
  * Fix several buffer issues.
  * New polar plots, and improved statistice, in gpsprof.
  * gpsd master/slave mode works, first time ever.
  * All isnan() changed to !isfinite(), fixing many bugs.
  * Client-side Python libraries may automatically reconnect
  * Too many other bug fixes and improvements to mention.
  * Over 1,000 commits from 46 different commiters.
- Update to version 3.17.0
  * Repair support for non-NMEA devices requring active probing
    (e.g. Garmin USB GPSes).
  * Fix a SiRF driver bug that occasionally confused NTP.
  * Support for Spectratime iSync GRClok and LNRClok oscillators.
  * gpxlogger can reconnect when the GPS loses the fix.
  * xgps and xgpsspeed moved to python-gi, getting shut of the
    deprecated pygtk2 bindings.
  * Default mode for xgpsspeed is now the more interesting nautical
    display.
  * gpsmon includes the hostname with the device display.
    gpsprof now has centimeter precision.
- Remove patch:
  * gpsd-python3.patch (not longer needed)
- Update gpsd.keyring (old key 8C6C738D got superseeded by 0C898D47 )
* Thu Jun 28 2018 mpluskal@suse.com
- Fix requires for gpsd-clients
- Cleanup spec file a bit
* Fri Jun 15 2018 stefan.bruens@rwth-aachen.de
- Require python3 versions for packages importing python modules, all
  scripts use python3 as interpreter.
* Fri Dec  1 2017 mimi.vx@gmail.com
- build with Qt5
- refreshed gpsd-python3.patch
* Tue Nov 28 2017 mimi.vx@gmail.com
- removed  gpsd-fix-shebang.patch
- reworked gpsd-python3.patch
- build python3 subpackage
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Mon Nov 20 2017 mpluskal@suse.com
- Update to version 3.17:
  * Repair support for non-NMEA devices requring active probing
    (e.g. Garmin USB GPSes).
  * Fix a SiRF driver bug that occasionally confused NTP.
  * Support for Spectratime iSync GRClok and LNRClok oscillators.
  * gpxlogger can reconnect when the GPS loses the fix.
  * xgps and xgpsspeed moved to python-gi,
    getting shut of the deprecated pygtk2 bindings.
  * Default mode for xgpsspeed is now the more interesting nautical
    display.
  * gpsmon includes the hostname with the device display.
  * gpsprof now has centimeter precision.
- Add gpsd-python3.patch to fix building with python3
- Fix shebangs of python script (currently still python2)
- Refresh gpsd-fix-shebang.patch
* Mon Nov 13 2017 mpluskal@suse.com
- Rename python subpackage to python2
* Thu Apr  6 2017 tchvatal@suse.com
- Remove conditionals for 1210 and older (oldest codebase built is SLE12)
- run scons in multiple threads
- convert to pkgconfig dependencies
* Tue Feb 28 2017 stefan.bruens@rwth-aachen.de
- Cleanup build/spec file:
  * Use .desktop files and PNG icon from tarball
  * correct flag to disable stripping (nostrip=True)
* Fri Aug 26 2016 mardnh@gmx.de
- Update gpsd.keyring (old key 8421F11C got superseeded by 8C6C738D)
- Added "-std=gnu++98" to the compile-flags otherwise compilation will break
  on systems with >= gcc6
- ifdef "Requires: pps-tools-devel" since it's only available on recent
  os-versions
- Update to version 3.16
  * Test rebuilds for mid-2015 leapsecond bump.
  * Regression tests will run even if "python" in Python 3.
  * Build correctly on systems where -ltinfo is split from -lncurses.
  * Avoid some rare overflow conditions in PPS code.
  * Fix bugs in JSON sat-view parsing due to the JSON parser stuffing
    ints into shorts.
  * Various small fixes to AIS interpretation.
  * Prevent a memory leak in long-running gpsmon instances.
  * Fix Savannah bug #45270: serial driver does not work properly on pipes.
  * Fix Savannah bug #44648: GPSD won't build if CCFLAGS contains options
    that are only compatible with the cros1s-compiler.
  * Fix Savannah bug #45342: SConstruct generates wrong *.pc files.
  * Fix Savannah bug #46495: gpsd_poll may crash due to unitialized pointer
    (probably due to buggy FD_ISSET on host system).
  * Fix Savannah bug #46648: gpsd crashes and buffer overflow is reported
    when terminated.
  * Fix Savannah bug #46802: AIVDM to CSV is broken in some weird cases.
  * Fix Savannah bug #46804: JSON satellite view parsing is somewhat broken.
* Tue Aug  9 2016 lnussel@suse.de
- use pkgconfig(udev) to always allow using udev-mini
* Mon Aug  8 2016 benoit.monin@gmx.fr
- add pps-tools-devel as BuildRequires to enable kernel PPS
* Mon Aug  1 2016 lnussel@suse.de
- use pkg-config to figure out udevdir. Fixes bootstrapping with
  udev-mini
* Tue Nov 24 2015 joop.boonen@opensuse.org
- Added missing requirements %%{libgps} and %%{libQgps} for devel package
* Sun Nov  8 2015 p.drouand@gmail.com
- Update to version 3.15
  * Fix a rare crash bug related to devices becomin inaccessible
    while timed out.
  * Accept NMEA 4.1 GSV sententences with the trailing signal-ID field.
  * Fixed incorrect decode of south latitudes in AIS Type 17 messages.
  * splint has been retired; this removes almost 2KLOC of annotations.
  * chrpath is no longer a build dependency. Corrected Beidou/QZNSS display
    in the Python clients so the graphics don't look like SBAS.
- Changes from version 3.14
  * Skyview support for the Beidou and QZSS constellations in the
    NMEA0183 driver.
  * ntpmon rename to ntpshmmon - it doesn't actually monitor NTP itself.
  * New HOWTO on the website: "Introduction to Time Service".
- Remove gpsd-3.13-ntpshm.patch; fixed on upstream release
* Sat Mar  7 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Add gpg signature
- Add gpsd-3.13-ntpshm.patch
- Install unit files
- Update to 3.13
  * compiler.h inclusion removed for gps.h so it's standalone
    for /usr/include.
  * TOFF JSON report gives the offset between GPS top of second and
    clock time.
  * A new ntpmon tool supports capturing clock samples from NTP
    SHM segments.
- Changes for 3.12
  * The daemon's power utilization has been reduced by changing
    from non-blocking to blocking I/O; this may be significant
    on mobile devices.
  * Better protection against false matches of Inland AIS messages;
    thisrequired a libgps version bump to 22 (as a side effect,
    per-devicefootprint has decreased).
  * PPS feature is no longer markedexperimental/unstable.
  * Sentence tag fields have been dropped from the JSON reports.
  * GNSS and GLONASS SKY reports are now merged.
  * Addressed versions of AIS Type 25 and 26 are now handled.
  * The 'nmea' build option is now 'nmea0183'.
  * New 'minimal' option sets all boolean options not explicitly
    set on the build command line to false.
  * The 'limited_max_devices' option is now 'max_devices'; the
    'limited_max_clients' option is now 'max_clients'
  * The previously deprecated 'libQgpsmm' option has been
    removed; use 'qt'.
  * A bug fix for error modeling when NMEA 0183 reports empty DOP fields.
  * On OS X, the "osx-pl203" driver has been explicitly listed
    as unsupported.
  * The last remnants of the old pre-JSON query protocol have
    been removed from the client library.
* Thu Jan 15 2015 p.drouand@gmail.com
- Update to version 3.11
  * A bug that prevented track interpolation has been fixed.
  * We now get vertical error position and speed estimates from the
    u-blox driver rather than having to interpolate them.
  * Some unusual AIS talker IDs (NMEA 4.0 station classes) are supported.
  * chrpath is no longer a dependency for building and testing, and
    now defaults to 'no'.
  * Full systemd support.
  * Fixes for handling large PPS offsets.
  * Improved recovery from device flakeouts, gpsmon argument parsing.
- Disable chrpath
* Tue Nov 25 2014 dl8fcl@darc.de
- Added python-gpsd requires for gpsd-clients
* Mon Oct  6 2014 crrodriguez@opensuse.org
- Respect CFLAGS and CXXFLAGS.
- Use fvisibility-inlines-hidden to build C++ code, note
  that the build system is buggy and uses CFLAGS and CXXFLAGS
  for the same purpose.
- Remove xorg libs buildrequires, they are never directly used.
* Mon Dec  9 2013 opensuse@dstoecker.de
- update to version 3.10
  AIS: Adds gps2udp, an AIS data relay, split24 option supports
  passing through Type 24 halves; support for Inland AIS; "scaled" no
  longer controls dumping of controlled-vocabulary fields; instead,
  the're always dumped numerically and as text, with text in an
  attribute name generated by appending "_text" to the name of the
  base attribute. The packetizer's handling of write boundaries not
  coinciding with packet boundaries is improved.  Better support for
  mode and speed switching in the UBX driver.  PPS message now ships
  nsec. PPS events are visible in gpsmon. Time-reporting fix to TSIP.
* Wed Nov 20 2013 suse@bugs.jan.ritzerfeld.org
- Fixed typo in udev rule (bnc#848936)
* Mon Oct 28 2013 p.drouand@gmail.com
- Update to version 3.9
  + Note to packagers: this is an urgent release that fixes a possible
    DoS or security hole!  Armor the AIS driver against an implausible
    overrun attack.  A (different) fix for our first malformed-packet
    crash since about 2007. Minor improvements to the NMEA2000
    driver. New FAQ entry on how to know WAAS/EGNOS is working.
  + New -u and -uu options enable usec timestamps on gpspipe output.
  For more please read usr/share/doc/packages/gpsd/NEWS
- Clean specfile and remove AUTHORS section
* Wed Oct 17 2012 fcrozat@suse.com
  1
- Fix build and adapt udev rule to new udev location.
* Mon Apr 23 2012 opensuse@dstoecker.de
- update to gpsd version 3.5
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Sat Oct 15 2011 andrea.turrini@gmail.com
- fixed typos in gpsd.spec
* Sat May 14 2011 dmueller@suse.de
- move libgpsd.so.0 from the shlib subpackage to the main package,
  as it fileconflicts with other versions of it. the library is
  internal only anyway.
* Sat Apr 30 2011 jw@novell.com
- gpsd-devel depends on python-gpsd too.
* Mon Apr  4 2011 devel@navlost.eu
- Update to version 2.96:
  + Bumped maximum channel count to 32 to accommodate GPS+GLONASS devices.
  + API version bumped to 5, redesign finished (changes are documented
    in the Client HOWTO).
  + cgps now handles resize signals.
  + Code can now link with uClibc for embedded use.
  + Various bugs in the C++ binding have been fixed.
  + gpxlogger can now daemonize and write to a specified log file.
  + A gpsd client can now set any locale it likes, and JSON
    will still be parsed using the C locale matching the daemon's.
  + Clients are no longer required to define a gpsd_report() hook.
  + gpsd no longer emits probe strings to unidentified USB devices at startup.
  + JSON timestamps in TPV and SKY are now ISO8601 rather than seconds since
    the Unix epoch; the library handles the older style backward-compatibly.
  + GPGST sentences are now parsed for noise statistics when a device emits
    them.
  + AIS and RTCM2 JSON dumps have device fields.
  + JSON reports now include 50bps subframe data if the device allows access to
    it.
  + gpsdecode can now dump NMEA GPS binary, and subframe data to JSON.
  + The RTCM2 code now understands and  analyzes RTCM2.3 messages 13,
    14, and 31, and has been checked against another analyzer.
  + The ancient Sager dump format for RTCM2 is abolished in favor of a JSON
    profile.
* Tue Oct 26 2010 jreuter@novell.com
- Move udev rules from /etc/udev/rules.d to /lib/udev/rules.d
- Update to version 2.95:
  + Rationalize clearing and generation of DOPs
  + cgps now displays epx/epy rather than eph
  + Speed is now always reported if our last two fixes were good
  + Reading packets from UDP datagrams by specifying a listening
    address and port is now supported
  + AIS code now interprets message type 6 and 8 application IDs
    correctly as a Designated Area Code and Functional ID pair
  + gpspipe has a new -T option for setting the timestamp format
  + xgpsspeed is completely rewritten in Python
  + Qt bindings for the client library
  + gpsdcode now uses | as a field separator in -c mode, as string
    fields can contain commas
  + Corrected error for reporting of AIS rate-of-turn fields
- Changes of version 2.94:
  + Error-checking in the 50bps subframe code has been greatly
    improved
  + The Garmin GPS driver can now use libusb for device discovery
  + The libgps library has been split apart; the service functions
    used by the daemon now live in libgpsd
  + Stronger checking for valid ephemeris before extracting the
    leap-second offset
- Changes of version 2.93:
  + Support for JSON dumping and parsing of AIS message types 25 and 26
  + Removing non-streaming mode from the Python exerciser
  + Unsetting the appropriate in-use flag in the device array
  + Change the libgps default from old protocol to JSON
  + Add a close() method to the C++ binding
  + Try to recover better from sporadic cases of false matches to
    Trimble packet format from a SiRF binary datastream
  + gps_poll() now returns -1 with errno not set when the gpsd
    socket closes
  + TPV now refrains from reporting fields the fix quality won't support
  + gpsmon option for listing device types is now -L to -l can be used
    to enable logging
  + Documentation updates
  + New POLL command brings back polling-mode operation
  + gpsd no longer eats CPU when a device is unexpectedly uplugged
  + Support for the TNT revolution is back (run mode only)
  + There is now a gpsdfake diagnostic tool that fakes being gpsd shipping
    arbitrary specified data to clients.
* Sat Mar 27 2010 vuntz@opensuse.org
- Update to version 2.92:
  + Fix a packaging error: the python library module was omitted
    from the 2.91 tarball.
  + Improve the json import test.
- Changes from version 2.91:
  + We have support for NMEA GLONASS sentences, and a regression
    test.
  + Clients now get a DEVICE notification on every driver switch.
  + It is possible to specify a TCP/IP AIS feed such as AISHub as a
    data source.
  + Serious bitrot in the NTRIP support has been fixed - it was
    probably nonfunctional for several releases before this.
  + Fixed buggy display of satellite-used flags in cgps.
  + xgps is replaced by a rewrite in Python that uses pygtk,
    eliminating a dependency on Motif; also, it now displays AIS
    information.
  + Uniform treatment of display-unit defaulting and -u in xgps,
    cgps, and lcdgps.
  + Support for AIS message types 25 and 26.
  + Support for IPv6.
  + A numeric instability in the earth_distance() function
    affecting track error modeling has been fixed.
  + Old protocol has been removed from the daemon; the library
    still speaks it.
- Drop openmotif, openmotif-devel BuildRequires.
- Add xorg-x11-devel, xorg-x11-libXpm-devel BuildRequires.
- Add gpsd-fix-python-install.patch to fix installation of the
  python bindings.
- Add python-gtk Requires to gpsd-clients subpackage as xgps now
  depends on it.
- Use a valid group for the devel subpackage.
- Do not manually strip executables: this will be done by the build
  service.
* Fri Feb 12 2010 jreuter@novell.com
- Add missing dependency to python-curses for devel package (bnc#574584)
- Add another Cyprus GPS USB id (bnc#574584)
* Fri Dec 18 2009 seife@opensuse.org
- fix udev warnings "SYSFS is deprecated"
* Tue Dec  8 2009 jreuter@novell.com
- Fix libgps subpackage requirements
* Tue Dec  8 2009 jreuter@novell.com
- Upgrade to gpsd-2.90, from the upstream change log:
  - GPSD-NG, the new JSON-based command protocol, is now deployed
  - Detection of end of a fix-reporting cycle is now reliable
  - Abandone gpsflash subproject
  - Increase major version of shared library due to significant API change
  - Add new driver for Motorola Oncore receivers
  - gpsfake can now accept multiple logfiles, interleaving test sentences
    from each.
  - gpsd now accepts error estimates from the NMEA $GPGBS sentence.
  - Fix potential core dump in C client handling of "K" responses
  - Introduce major and minor API version symbols into the public interfaces
  - The sirfmon utility is gone, replaced by gpsmon
  - Fix an old error in NMEA parsing
  - cgpxlogger has been merged into gpxlogger.
  - Speed-setting commands now allow parity and stop-bit setting
  - tcmdecode becomes gpsdecode and can now de-armor and dump AIDVM packets
  - The clientlibrary now works correctly in locales where the decimal
    separator is not a period.
- Typo in sirfmon / gpsmon has been fixed silently by upstream (#bnc513037)
- Make libgps and python modules subpackages
* Sun Aug  9 2009 coolo@novell.com
- use new python macros
* Mon Nov 24 2008 jreuter@suse.de
- Disable TrueNorth Technologies device support, it breaks
  autodection (bnc#448002)
- Fix udev script again: must not kill running gpsd if disabled,
  missing quotes in test, indention, add parameter to set additional
  command line options for gpsd.
* Wed Nov 19 2008 jreuter@suse.de
- Sleep a second before setting the default device in udev
  script to give gpsd some time to set up the TCP socket
* Thu Oct 23 2008 jreuter@suse.de
- Disable start of gpsd by udev rule by default and add sysconfig
  variable to enable it if desired (bnc#432420)
* Thu Apr 24 2008 jreuter@suse.de
- Fix RPM group tag for devel package
- Cleanup spec file
* Sat Mar 22 2008 lrupp@suse.de
- update to 2.37
  Fixes:
  + C++ bindings
  + Garmin USB support
  + multiple instances of ntp pps thread starting
  + better handling of odd PPS signals
  + eye candy in the php visualizers
- enable Garmin Simple Text support
- enable True North Technologies support
- disable static
- mark man files as %%doc
- added desktop entries
- fix ldconfig calls
- clean buildroot
- PreReq coreutils and fillup_prereq for postinstall
* Fri Jan 18 2008 jreuter@suse.de
- updated to 2.36
  * Integrated Garmin Simple Text Protocol driver from Peter Slansky.
  * Stabilize the Trimble regression tests.
  * Remove the wired-in NTP time offset from the NMEA driver
  * Integrate Ashtech driver from Chris Kuethe.
- Submit to STABLE for 11.0
* Thu Dec 13 2007 opensuse@dstoecker.de
- updated to 2.35
* Tue Nov 20 2007 anschneider@suse.de
- update udev rules and script
* Fri Jun 29 2007 anschneider@suse.de
- Spec file cleanup
* Sun Dec 17 2006 anschneider@suse.de
- update to version 2.34:
  * Fix for byte-swapping of Zodiac control messages on big-endian hardware.
  * Disable iTalk by default and note that it needs to be tested.
  * Command line arguments can now be DGPSIP or NTRIP URLs; -d is
    deprecated.
  * Added udev rules.
  * Address excessive processor and memory utilization on SBCs; it's now
    possible to configure compile-time limits on the number of devices and
    client sessions.
  * Eliminate use of fuser(1) in gpsfake.
  * Get gpsd working with EarthMates again, this had been broken since 2.15.
    Massive string safety audit and OpenBSD port by Chris Kuethe.
  * J command added.
  * The gpsctl and gpscat tools and the gpsd.phps script were added.
  * Switched to lesstif from openmotif.
  * Better autodetection of DLE-led packet protocols (notably TSIP and Garmin
    binary) and of SiRFStar I and III devices.
  * Fixed buggy parsing and generation of PGRME.
* Mon Jun  5 2006 anschneider@suse.de
- Initial package
